#!/bin/sh

basedir="/usr/local"

if [ "$1" = "-update" -o "$1" = "--update" ]; then
	if [ -f $HOME/alisp/.version ]; then
		version=`cat $HOME/alisp/.version`
	else
		version=6
	fi
	if [ \
		$version != 7 \
		-a $version != 8 \
		-a $version != 9 \
		-a $version != 10 \
		-a $version != 11 \
		-a $version != 12 \
	]; then
		echo
		echo "WARNING: You are about to upgrade from a"
		echo "pre-7 version of ArrowLISP to ArrowLISP 12."
		echo
		echo "After this step, some programs may no"
		echo "longer run as expected. Please consult the"
		echo "ArrowLISP manual before doing this step."
		echo
		echo "This step will also replace the example"
		echo "programs in $HOME/alisp/src."
		echo
		echo -n "Are you sure you want to upgrade now? (y/n) "
		read x
		case $x in
			y|yes|Y|Yes|YES)
				;;
			*)
				exit 0 ;;
		esac
		echo '12' >$HOME/alisp/.version
	fi
	if [ ! -d $HOME/alisp/ext ]; then
		mkdir $HOME/alisp/ext
	fi
	cp $basedir/share/alisp/lib/*.l $HOME/alisp/lib
	cp $basedir/share/alisp/ext/*.l $HOME/alisp/ext
	echo
	echo "Your ArrowLISP library files in $HOME/alisp/lib"
	echo "have been udated."
	echo
	echo -n \
	"Replace the example files in your $HOME/alisp/src directory? (y/n) "
	read x
	echo
	case $x in
		y|yes|Y|Yes|YES)
			cp $basedir/share/alisp/src/*.[lm] $HOME/alisp/src
			echo "Your $HOME/alisp/src directory has been updated"
			echo
			;;
	esac
	exit 0
fi

if [ -d $HOME/alisp ]; then
	echo
	echo "Your ArrowLISP environment is already set up."
	echo "Its base directory is $HOME/alisp."
	echo
	echo "You may run alisp_install with the --update"
	echo "option to update the library files."
	echo
	exit 1
fi

mkdir $HOME/alisp
mkdir $HOME/alisp/ext
mkdir $HOME/alisp/lib
mkdir $HOME/alisp/src

cp $basedir/share/alisp/lib/*.l $HOME/alisp/lib
cp $basedir/share/alisp/ext/*.l $HOME/alisp/ext
cp $basedir/share/alisp/src/*.[lm] $HOME/alisp/src

echo '12' >$HOME/alisp/.version

echo
echo "Your ArrowLISP base directory is $HOME/alisp"
echo
